@@ -9,7 +9,7 @@ Kafka - Apache Kafka interface for Perl.
 
 =head1 VERSION
 
-This documentation refers to C<Kafka> package version 0.800_12 .
+This documentation refers to C<Kafka> package version 0.800_13 .
 
 =cut
 
@@ -21,7 +21,7 @@ use warnings;
 
 # ENVIRONMENT ------------------------------------------------------------------
 
-our $VERSION = '0.800_12';
+our $VERSION = '0.800_13';
 
 use Exporter qw(
     import
@@ -1058,6 +1058,13 @@ L<Kafka::IO-E<gt>new|Kafka::IO/new>' uses L<Sys::SigAction|Sys::SigAction> and C
 to limit some internal operations. This means that if an external C<alarm()> was set, signal
 delivery may be delayed.
 
+With non-empty timeout, we use alarm internally and try preserving existing alarm if possible.
+However, if L<Time::HiRes::ualarm|Time::HiRes/ualarm> is set before calling Kafka modules,
+its behaviour is unspecified (i.e. it could be reset or preserved etc.).
+
+For C<gethostbyname> operations the non-empty timeout is rounded to the nearest positive integer;
+any timeouts less than 1 second are rounded to 1 second.
+
 You can disable the use of C<alarm()> by setting C<timeout =E<gt> undef> in the constructor.
 
 The Kafka package was written, tested, and found working on recent Linux distributions.
